@@ -16,24 +16,31 @@ package Spreadsheet::Read;
  my $book  = ReadData ("test.xlsx");
  my $book  = ReadData ($fh, parser => "xls");
 
+ Spreadsheet::Read::add ($book, "sheet.csv");
+
  my $sheet = $book->[1];             # first datasheet
  my $cell  = $book->[1]{A3};         # content of field A3 of sheet 1
  my $cell  = $book->[1]{cell}[1][3]; # same, unformatted
 
+ # OO API
+ my $book = Spreadsheet::Read->new ("file.csv");
+ $book->add ("test.xls");
+
 =cut
 
 use strict;
 use warnings;
 
-our $VERSION = "0.63";
+our $VERSION = "0.69";
 sub  Version { $VERSION }
 
 use Carp;
 use Exporter;
 our @ISA       = qw( Exporter );
 our @EXPORT    = qw( ReadData cell2cr cr2cell );
-our @EXPORT_OK = qw( parses rows cellrow row );
+our @EXPORT_OK = qw( parses rows cellrow row add );
 
+use Encode       qw( decode );
 use File::Temp   qw( );
 use Data::Dumper;
 
@@ -46,7 +53,6 @@ my @parsers = (
     [ xls  => "Spreadsheet::ParseExcel",		"0.34"		],
     [ xlsx => "Spreadsheet::ParseXLSX",			"0.13"		],
     [ xlsx => "Spreadsheet::XLSX",			"0.13"		],
-    [ xlsx => "Spreadsheet::XLSX::Reader::LibXML",	"v9.99.99"	],
     [ prl  => "Spreadsheet::Perl",			""		],
 
     # Helper modules
@@ -121,12 +127,12 @@ my @def_attr = (
     hidden  => 0,
     locked  => 0,
     enc     => "utf-8", # $ENV{LC_ALL} // $ENV{LANG} // ...
+    formula => undef,
     );
 
 # Helper functions
 
-sub _dump
-{
+sub _dump {
     my ($label, $ref) = @_;
     if ($can{dmp}) {
 	print STDERR Data::Peek::DDumper ({ $label => $ref });
@@ -136,8 +142,7 @@ sub _dump
 	}
     } # _dump
 
-sub _parser
-{
+sub _parser {
     my $type = shift		or  return "";
     $type = lc $type;
     # Aliases and fullnames
@@ -152,18 +157,35 @@ sub _parser
     return exists $can{$type} ? $type : "";
     } # _parser
 
+sub new {
+    my $class = shift;
+    my $r = ReadData (@_) || [{
+	parsers	=> [],
+	error	=> undef,
+	sheets	=> 0,
+	sheet	=> { },
+	}];
+    bless $r => $class;
+    } # new
+
 # Spreadsheet::Read::parses ("csv") or die "Cannot parse CSV"
-sub parses
-{
+sub parses {
+    ref $_[0] eq __PACKAGE__ and shift;
     my $type = _parser (shift)	or  return 0;
     $can{$type} =~ m/^!/ and return 0;
     return $can{$type};
     } # parses
 
+sub sheets {
+    my $ctrl = shift->[0];
+    my %s = %{$ctrl->{sheet}};
+    wantarray ? sort { $s{$a} <=> $s{$b} } keys %s : $ctrl->{sheets};
+    } # sheets
+
 # cr2cell (4, 18) => "D18"
 # No prototype to allow 'cr2cell (@rowcol)'
-sub cr2cell
-{
+sub cr2cell {
+    ref $_[0] eq __PACKAGE__ and shift;
     my ($c, $r) = @_;
     defined $c && defined $r && $c > 0 && $r > 0 or return "";
     my $cell = "";
@@ -177,8 +199,8 @@ sub cr2cell
     } # cr2cell
 
 # cell2cr ("D18") => (4, 18)
-sub cell2cr
-{
+sub cell2cr {
+    ref $_[0] eq __PACKAGE__ and shift;
     my ($cc, $r) = (uc ($_[0]||"") =~ m/^([A-Z]+)([0-9]+)$/) or return (0, 0);
     my $c = 0;
     while ($cc =~ s/^([A-Z])//) {
@@ -188,9 +210,9 @@ sub cell2cr
     } # cell2cr
 
 # my @row = cellrow ($book->[1], 1);
-sub cellrow
-{
-    my $sheet = shift or return;
+# my @row = $book->cellrow (1, 1);
+sub cellrow {
+    my $sheet = ref $_[0] eq __PACKAGE__ ? (shift)->[shift] : shift or return;
     ref     $sheet eq "HASH" && exists  $sheet->{cell}   or return;
     exists  $sheet->{maxcol} && exists  $sheet->{maxrow} or return;
     my $row   = shift or return;
@@ -200,9 +222,8 @@ sub cellrow
     } # cellrow
 
 # my @row = row ($book->[1], 1);
-sub row
-{
-    my $sheet = shift or return;
+sub row {
+    my $sheet = ref $_[0] eq __PACKAGE__ ? (shift)->[shift] : shift or return;
     ref     $sheet eq "HASH" && exists  $sheet->{cell}   or return;
     exists  $sheet->{maxcol} && exists  $sheet->{maxrow} or return;
     my $row   = shift or return;
@@ -212,9 +233,8 @@ sub row
 
 # Convert {cell}'s [column][row] to a [row][column] list
 # my @rows = rows ($book->[1]);
-sub rows
-{
-    my $sheet = shift or return;
+sub rows {
+    my $sheet = ref $_[0] eq __PACKAGE__ ? (shift)->[shift] : shift or return;
     ref    $sheet eq "HASH" && exists $sheet->{cell}   or return;
     exists $sheet->{maxcol} && exists $sheet->{maxrow} or return;
     my $s = $sheet->{cell};
@@ -225,10 +245,20 @@ sub rows
 	} 1..$sheet->{maxrow};
     } # rows
 
+sub sheet {
+    my ($book, $sheet) = @_;
+    $book && $sheet or return;
+    my $class = "Spreadsheet::Read::Sheet";
+    $sheet =~ m/^[0-9]+$/ && $sheet >= 1 && $sheet <= $book->[0]{sheets} and
+	return bless $book->[$sheet]			=> $class;
+    exists $book->[0]{sheet}{$sheet} and
+	return bless $book->[$book->[0]{sheet}{$sheet}]	=> $class;
+    return;
+    } # sheet
+
 # If option "clip" is set, remove the trailing rows and
 # columns in each sheet that contain no visible data
-sub _clipsheets
-{
+sub _clipsheets {
     my ($opt, $ref) = @_;
 
     if (my $s = $opt->{strip} and $ref->[0]{sheets}) {
@@ -280,8 +310,7 @@ sub _clipsheets
     } # _clipsheets
 
 # Convert a single color (index) to a color
-sub _xls_color
-{
+sub _xls_color {
     my $clr = shift;
     defined $clr		or  return undef;
     $clr eq "#000000"		and return undef;
@@ -291,8 +320,7 @@ sub _xls_color
     } # _xls_color
 
 # Convert a fill [ $pattern, $front_color, $back_color ] to a single background
-sub _xls_fill
-{
+sub _xls_fill {
     my ($p, $fg, $bg) = @_;
     defined $p			or  return undef;
     $p == 32767			and return undef; # Default fg color
@@ -302,8 +330,7 @@ sub _xls_fill
     return _xls_color ($bg);
     } # _xls_fill
 
-sub _xlsx_libxml
-{
+sub _xlsx_libxml {
     my $oBook = shift;
     my @names = @{$oBook->get_worksheet_names};
     $oBook->{SheetCount} = scalar @names;
@@ -338,7 +365,7 @@ sub _xlsx_libxml
 		$wks->{Cells}[$r][$c] = $cell;
 		}
 	    }
-	# Spreadsheet::XLSX::Reader::LibXML returns all other cells in range as undef
+	# Spreadsheet::XLSX::Reader::LibXML returned all other cells in range as undef
 	foreach my $mm (values %mm) {
 	    my @mr = sort keys %$mm;
 	    foreach my $rc (@mr) {
@@ -346,10 +373,6 @@ sub _xlsx_libxml
 		}
 	    }
 	}
-    *Spreadsheet::XLSX::Reader::LibXML::Cell::Value = sub {
-	my $cell = shift;
-	$cell->value;
-	};
     *WorksheetInstance::get_merged_areas = sub {
 	my $wi = shift or return;
 	my $mm = eval { $wi->_get_merge_map } ||
@@ -389,8 +412,7 @@ sub _xlsx_libxml
 	};
     } # _xlsx_libxml
 
-sub ReadData
-{
+sub ReadData {
     my $txt = shift	or  return;
 
     my %opt;
@@ -427,24 +449,30 @@ sub ReadData
 
 	my $label = $io_fil ? $txt : "IO";
 
-	$debug and print STDERR "Opening CSV $label\n";
+	$debug and print STDERR "Opening CSV $label using $can{csv}-", $can{csv}->VERSION, "\n";
 
 	my @data = (
 	    {	type	=> "csv",
-		parser  => $can{csv},
+		parser	=> $can{csv},
 		version	=> $can{csv}->VERSION,
+		parsers	=> [ {
+		    type	=> "csv",
+		    parser	=> $can{csv},
+		    version	=> $can{csv}->VERSION,
+		    }],
 		error	=> undef,
-		quote   => '"',
-		sepchar => ',',
+		quote	=> '"',
+		sepchar	=> ',',
 		sheets	=> 1,
 		sheet	=> { $label => 1 },
 		},
-	    {	label	=> $label,
+	    {	parser	=> 0,
+		label	=> $label,
 		maxrow	=> 0,
 		maxcol	=> 0,
 		cell	=> [],
 		attr	=> [],
-		merged  => [],
+		merged	=> [],
 		},
 	    );
 
@@ -535,7 +563,7 @@ sub ReadData
 	my $parser = $can{lc $parse_type} or
 	    croak "Parser for $parse_type is not installed";
 	my $xlsx_libxml = $parser =~ m/LibXML$/;
-	$debug and print STDERR "Opening $parse_type \$txt\n";
+	$debug and print STDERR "Opening $parse_type $txt using $parser-", $can{lc $parse_type}->VERSION, "\n";
 	my $oBook = eval {
 	    $io_ref
 	      ? $parse_type eq "XLSX"
@@ -556,16 +584,30 @@ sub ReadData
 	    }
 	$debug > 8 and _dump (oBook => $oBook);
 
+	# WorkBook keys:
+	# aColor         _CurSheet      Format         SheetCount
+	# ActiveSheet    _CurSheet_     FormatStr      _skip_chart
+	# Author         File           NotSetCell     _string_contin
+	# BIFFVersion    Flg1904        Object         Version
+	# _buffer        FmtClass       PkgStr         Worksheet
+	# CellHandler    Font           _previous_info
+
 	$xlsx_libxml and _xlsx_libxml ($oBook);
 
 	my @data = ( {
 	    type	=> lc $parse_type,
 	    parser	=> $can{lc $parse_type},
 	    version	=> $can{lc $parse_type}->VERSION,
+	    parsers	=> [{
+		type	=> lc $parse_type,
+		parser	=> $can{lc $parse_type},
+		version	=> $can{lc $parse_type}->VERSION,
+		}],
 	    error	=> undef,
 	    sheets	=> $oBook->{SheetCount} || 0,
 	    sheet	=> {},
 	    } );
+	# $debug and $data[0]{_parser} = $oBook;
 	# Overrule the default date format strings
 	my %def_fmt = (
 	    0x0E	=> lc $opt{dtfmt},	# m-d-yy
@@ -576,16 +618,15 @@ sub ReadData
 	$oBook->{FormatStr}{$_} = $def_fmt{$_} for keys %def_fmt;
 	my $oFmt = $parse_type eq "XLSX"
 	    ? $can{xlsx} =~ m/::XLSX$/
-	    ? Spreadsheet::XLSX::Fmt2007->new
-	    : $can{xlsx} =~ m/::XLSX/
-	    ? Spreadsheet::XLSX::Reader::LibXML::FmtDefault->new
-	    : Spreadsheet::ParseExcel::FmtDefault->new
-	    : Spreadsheet::ParseExcel::FmtDefault->new;
+		? Spreadsheet::XLSX::Fmt2007->new
+		: Spreadsheet::ParseExcel::FmtDefault->new
+	    :     Spreadsheet::ParseExcel::FmtDefault->new;
 
 	$debug and print STDERR "\t$data[0]{sheets} sheets\n";
 	foreach my $oWkS (@{$oBook->{Worksheet}}) {
 	    $opt{clip} and !defined $oWkS->{Cells} and next; # Skip empty sheets
 	    my %sheet = (
+		parser	=> 0,
 		label	=> $oWkS->{Name},
 		maxrow	=> 0,
 		maxcol	=> 0,
@@ -593,6 +634,7 @@ sub ReadData
 		attr	=> [],
 		merged  => [],
 		);
+	    # $debug and $sheet{_parser} = $oWkS;
 	    defined $sheet{label}  or  $sheet{label}  = "-- unlabeled --";
 	    exists $oWkS->{MinRow} and $sheet{minrow} = $oWkS->{MinRow} + 1;
 	    exists $oWkS->{MaxRow} and $sheet{maxrow} = $oWkS->{MaxRow} + 1;
@@ -606,7 +648,24 @@ sub ReadData
 		@{$oWkS->get_merged_areas || []}];
 	    my $sheet_idx = 1 + @data;
 	    $debug and print STDERR "\tSheet $sheet_idx '$sheet{label}' $sheet{maxrow} x $sheet{maxcol}\n";
+	    # Sheet keys:
+	    # _Book          FooterMargin   MinCol         RightMargin
+	    # BottomMargin   FooterMergin   MinRow         RightMergin
+	    # BottomMergin   HCenter        Name           RowHeight
+	    # Cells          Header         NoColor        RowHidden
+	    # ColFmtNo       HeaderMargin   NoOrient       Scale
+	    # ColHidden      HeaderMergin   NoPls          SheetHidden
+	    # ColWidth       Kind           Notes          _SheetNo
+	    # Copis          Landscape      PageFit        SheetType
+	    # DefColWidth    LeftMargin     PageStart      SheetVersion
+	    # DefRowHeight   LeftMergin     PaperSize      TopMargin
+	    # Draft          LeftToRight    _Pos           TopMergin
+	    # FitHeight      MaxCol         PrintGrid      UsePage
+	    # FitWidth       MaxRow         PrintHeaders   VCenter
+	    # Footer         MergedArea     Res            VRes
 	    if (exists $oWkS->{MinRow}) {
+		my $hiddenRows = $oWkS->{RowHidden} || [];
+		my $hiddenCols = $oWkS->{ColHidden} || [];
 		if ($opt{clip}) {
 		    my ($mr, $mc) = (-1, -1);
 		    foreach my $r ($oWkS->{MinRow} .. $sheet{maxrow}) {
@@ -625,6 +684,9 @@ sub ReadData
 			my $oWkC = $oWkS->{Cells}[$r][$c] or next;
 			#defined (my $val = $oWkC->{Val}) or next;
 			my $val = $oWkC->{Val};
+			if (defined $val and my $enc = $oWkC->{Code}) {
+			    $enc eq "ucs2" and $val = decode ("utf-16be", $val);
+			    }
 			my $cell = cr2cell ($c + 1, $r + 1);
 			$opt{rc} and $sheet{cell}[$c + 1][$r + 1] = $val;	# Original
 
@@ -645,14 +707,6 @@ sub ReadData
 			    }
 			exists $FmT->{Fill} or $FmT->{Fill} = [ 0 ];
 			exists $FmT->{Font} or $FmT->{Font} = undef;
-			if ($xlsx_libxml and
-			     ref $oWkC eq "Spreadsheet::XLSX::Reader::LibXML::Cell" and
-			     my $style = $oWkC->get_fill) {
-			    if (my $pf = $style->{patternFill}) {
-				#defined $pf->{fgColor}{indexed} and $FmT->{Font}{Color} =   $pf->{fgColor}{indexed};
-				#defined $pf->{bgColor}{indexed} and $FmT->{Fill}        = [ $pf->{bgColor}{indexed} ];
-				}
-			    }
 
 			unless (defined $fmt) {
 			    $fmt = $FmT->{FmtIdx}
@@ -691,7 +745,8 @@ sub ReadData
 				type    => lc $oWkC->{Type},
 				enc     => $oWkC->{Code},
 				merged  => (defined $oWkC->{Merged} ? $oWkC->{Merged} : $oWkC->is_merged) || 0,
-				hidden  => (defined $oWkC->{Hidden} ? $oWkC->{Hidden} : $FmT->{Hidden})   || 0,
+				hidden  => ($hiddenRows->[$r] || $hiddenCols->[$c] ? 1 :
+					    defined $oWkC->{Hidden} ? $oWkC->{Hidden} : $FmT->{Hidden})   || 0,
 				locked  => $FmT->{Lock}     || 0,
 				format  => $fmi,
 				halign  => [ undef, qw( left center right
@@ -707,6 +762,7 @@ sub ReadData
 				uline   => $FnT->{Underline},
 				fgcolor => _xls_color ($FnT->{Color}),
 				bgcolor => _xls_fill  (@{$FmT->{Fill}}),
+				formula => $oWkC->{Formula},
 				};
 			    #_dump "cell", $sheet{attr}[$c + 1][$r + 1];
 			    }
@@ -748,11 +804,17 @@ sub ReadData
 	    {	type	=> "sc",
 		parser	=> "Spreadsheet::Read",
 		version	=> $VERSION,
+		parsers	=> [{
+		    type	=> "sc",
+		    parser	=> "Spreadsheet::Read",
+		    version	=> $VERSION,
+		    }],
 		error	=> undef,
 		sheets	=> 1,
 		sheet	=> { sheet => 1 },
 		},
-	    {	label	=> "sheet",
+	    {	parser	=> 0,
+		label	=> "sheet",
 		maxrow	=> 0,
 		maxcol	=> 0,
 		cell	=> [],
@@ -787,20 +849,21 @@ sub ReadData
     if ($opt{parser} ? _parser ($opt{parser}) eq "sxc"
 		     : ($txt =~ m/^<\?xml/ or -f $txt)) {
 	$can{sxc} or croak "Spreadsheet::ReadSXC not installed";
+	my $using = "using $can{sxc}-" . $can{sxc}->VERSION;
 	my $sxc_options = { %parser_opts, OrderBySheet => 1 }; # New interface 0.20 and up
 	my $sxc;
 	   if ($txt =~ m/\.(sxc|ods)$/i) {
-	    $debug and print STDERR "Opening \U$1\E $txt\n";
+	    $debug and print STDERR "Opening \U$1\E $txt $using\n";
 	    $sxc = Spreadsheet::ReadSXC::read_sxc      ($txt, $sxc_options)	or  return;
 	    }
 	elsif ($txt =~ m/\.xml$/i) {
-	    $debug and print STDERR "Opening XML $txt\n";
+	    $debug and print STDERR "Opening XML $txt $using\n";
 	    $sxc = Spreadsheet::ReadSXC::read_xml_file ($txt, $sxc_options)	or  return;
 	    }
 	# need to test on pattern to prevent stat warning
 	# on filename with newline
 	elsif ($txt !~ m/^<\?xml/i and -f $txt) {
-	    $debug and print STDERR "Opening XML $txt\n";
+	    $debug and print STDERR "Opening XML $txt $using\n";
 	    open my $f, "<", $txt	or  return;
 	    local $/;
 	    $txt = <$f>;
@@ -814,6 +877,11 @@ sub ReadData
 		type	=> "sxc",
 		parser	=> "Spreadsheet::ReadSXC",
 		version	=> $Spreadsheet::ReadSXC::VERSION,
+		parsers	=> [{
+		    type	=> "sxc",
+		    parser	=> "Spreadsheet::ReadSXC",
+		    version	=> $Spreadsheet::ReadSXC::VERSION,
+		    }],
 		error	=> undef,
 		sheets	=> 0,
 		sheet	=> {},
@@ -828,6 +896,7 @@ sub ReadData
 	    foreach my $sheet (@sheets) {
 		my @sheet = @{$sheet->{data}};
 		my %sheet = (
+		    parser => 0,
 		    label  => $sheet->{label},
 		    maxrow => scalar @sheet,
 		    maxcol => 0,
@@ -864,6 +933,99 @@ sub ReadData
     return;
     } # ReadData
 
+sub add {
+    my $book = shift;
+    my $r = ReadData (@_) or return;
+    $book && (ref $book eq "ARRAY" || ref $book eq __PACKAGE__) && $book->[0]{sheets} or return $r;
+
+    my $c1 = $book->[0];
+    my $c2 = $r->[0];
+
+    unless ($c1->{parsers}) {
+	$c1->{parsers}[0]{$_} = $c1->{$_} for qw( type parser version );
+	$book->[$_]{parser} = 0 for 1 .. $c1->{sheets};
+	}
+    my ($pidx) = (grep { my $p = $c1->{parsers}[$_];
+	$p->{type}    eq $c2->{type}   &&
+	$p->{parser}  eq $c2->{parser} &&
+	$p->{version} eq $c2->{version} } 0 .. $#{$c1->{parsers}});
+    unless (defined $pidx) {
+	$pidx = scalar @{$c1->{parsers}};
+	$c1->{parsers}[$pidx]{$_} = $c2->{$_} for qw( type parser version );
+	}
+
+    foreach my $sn (sort { $c2->{sheet}{$a} <=> $c2->{sheet}{$b} } keys %{$c2->{sheet}}) {
+	my $s = $sn;
+	my $v = 2;
+	while (exists $c1->{sheet}{$s}) {
+	    $s = $sn."[".$v++."]";
+	    }
+	$c1->{sheet}{$s} = $c1->{sheets} + $c2->{sheet}{$sn};
+	$r->[$c2->{sheet}{$sn}]{parser} = $pidx;
+	push @$book, $r->[$c2->{sheet}{$sn}];
+	}
+    $c1->{sheets} += $c2->{sheets};
+
+    return $book;
+    } # add
+
+package Spreadsheet::Read::Sheet;
+
+sub cell {
+    my ($sheet, @id) = @_;
+    @id == 2 && $id[0] =~ m/^[0-9]+$/ && $id[1] =~ m/^[0-9]+$/ and
+	return $sheet->{cell}[$id[0]][$id[1]];
+    @id && $id[0] && exists $sheet->{$id[0]} and
+	return $sheet->{$id[0]};
+    } # cell
+
+sub maxrow {
+    my $sheet = shift;
+    return $sheet->{maxrow};
+    } # maxrow
+
+sub maxcol {
+    my $sheet = shift;
+    return $sheet->{maxcol};
+    } # maxrow
+
+sub cr2cell {
+    my $class = shift;
+    return Spreadsheet::Read::cr2cell (@_);
+    } # cr2cell
+
+sub cell2cr {
+    my $class = shift;
+    return Spreadsheet::Read::cell2cr (@_);
+    } # cell2cr
+
+# my @row = $sheet->cellrow (1);
+sub cellrow {
+    my ($sheet, $row) = @_;
+    defined $row && $row > 0 && $row <= $sheet->{maxrow} or return;
+    my $s = $sheet->{cell};
+    map { $s->[$_][$row] } 1..$sheet->{maxcol};
+    } # cellrow
+
+# my @row = $sheet->row (1);
+sub row {
+    my ($sheet, $row) = @_;
+    defined $row && $row > 0 && $row <= $sheet->{maxrow} or return;
+    map { $sheet->{$sheet->cr2cell ($_, $row)} } 1..$sheet->{maxcol};
+    } # row
+
+# Convert {cell}'s [column][row] to a [row][column] list
+# my @rows = $sheet->rows ();
+sub rows {
+    my $sheet = shift;
+    my $s = $sheet->{cell};
+
+    map {
+	my $r = $_;
+	[ map { $s->[$_][$r] } 1..$sheet->{maxcol} ];
+	} 1..$sheet->{maxrow};
+    } # rows
+
 1;
 
 __END__
@@ -897,13 +1059,16 @@ The data is returned as an array reference:
           "Sheet 1"  => 1,
           "Sheet 2"  => 2,
           },
-        type    => "xls",
-        parser  => "Spreadsheet::ParseExcel",
-        version => 0.59,
-	error	=> undef,
+        parsers => [ {
+            type    => "xls",
+            parser  => "Spreadsheet::ParseExcel",
+            version => 0.59,
+            }],
+        error   => undef,
         },
       # Entry 1 is the first sheet
-      { label   => "Sheet 1",
+      { parser  => 0,
+        label   => "Sheet 1",
         maxrow  => 2,
         maxcol  => 4,
         cell    => [ undef,
@@ -916,7 +1081,8 @@ The data is returned as an array reference:
         B5      => "Nugget",
         },
       # Entry 2 is the second sheet
-      { label   => "Sheet 2",
+      { parser  => 0,
+        label   => "Sheet 2",
         :
         :
 
@@ -934,7 +1100,13 @@ the sheets when accessing them by name:
 
   my %sheet2 = %{$book->[$book->[0]{sheet}{"Sheet 2"}]};
 
-=head2 Functions
+=head2 Functions and methods
+
+=head3 new
+
+ my $book = Spreadsheet::Read->new (...);
+
+All options accepted by ReadData are accepted by new.
 
 =head3 ReadData
 
@@ -1057,7 +1229,9 @@ that parser supports attributes.
 
 =head3 cr2cell
 
- my $cell = cr2cell (col, row)
+ my $cell = cr2cell (col, row);
+
+ my $cell = $book->cr2cell (col, row);  # OO
 
 C<cr2cell ()> converts a C<(column, row)> pair (1 based) to the
 traditional cell notation:
@@ -1067,7 +1241,9 @@ traditional cell notation:
 
 =head3 cell2cr
 
- my ($col, $row) = cell2cr ($cell)
+ my ($col, $row) = cell2cr ($cell);
+
+ my ($col, $row) = $book->cell2cr ($cell);  # OO
 
 C<cell2cr ()> converts traditional cell notation to a C<(column, row)>
 pair (1 based):
@@ -1079,7 +1255,9 @@ pair (1 based):
 
  my @row = row ($sheet, $row)
 
- my @row = Spreadsheet::Read::row ($book->[1], 3)
+ my @row = Spreadsheet::Read::row ($book->[1], 3);
+
+ my @row = $book->row ($sheet, $row); # OO
 
 Get full row of formatted values (like C<< $sheet->{A3} .. $sheet->{G3} >>)
 
@@ -1090,22 +1268,26 @@ use argument list, or call it fully qualified.
 
 =head3 cellrow
 
- my @row = cellrow ($sheet, $row)
+ my @row = cellrow ($sheet, $row);
 
- my @row = Spreadsheet::Read::cellrow ($book->[1], 3)
+ my @row = Spreadsheet::Read::cellrow ($book->[1], 3);
+
+ my @row = $book->cellrow ($sheet, $row); # OO
 
 Get full row of unformatted values (like C<< $sheet->{cell}[1][3] .. $sheet->{cell}[7][3] >>)
 
 Note that the indexes in the returned list are 0-based.
 
 C<cellrow ()> is not imported by default, so either specify it in the
-use argument list, or call it fully qualified.
+use argument list, or call it fully qualified or as method call.
 
 =head3 rows
 
- my @rows = rows ($sheet)
+ my @rows = rows ($sheet);
 
- my @rows = Spreadsheet::Read::rows ($book->[1])
+ my @rows = Spreadsheet::Read::rows ($book->[1]);
+
+ my @rows = $book->rows (1); # OO
 
 Convert C<{cell}>'s C<[column][row]> to a C<[row][column]> list.
 
@@ -1117,9 +1299,11 @@ use argument list, or call it fully qualified.
 
 =head3 parses
 
- parses ($format)
+ parses ($format);
 
- Spreadsheet::Read::parses ("CSV")
+ Spreadsheet::Read::parses ("CSV");
+
+ $book->parses ("CSV"); # OO
 
 C<parses ()> returns Spreadsheet::Read's capability to parse the
 required format. L<C<ReadData>|/ReadData> will pick its preferred parser
@@ -1136,6 +1320,8 @@ use argument list, or call it fully qualified.
 
  my $v = Spreadsheet::Read->VERSION;
 
+ my $v = $book->Version (); # OO
+
 Returns the current version of Spreadsheet::Read.
 
 C<Version ()> is not imported by default, so either specify it in the
@@ -1144,6 +1330,100 @@ use argument list, or call it fully qualified.
 This function returns exactly the same as C<< Spreadsheet::Read->VERSION >>
 returns and is only kept for backward compatibility reasons.
 
+=head3 sheets
+
+ my $sheets = $book->sheets; # OO
+ my @sheets = $book->sheets; # OO
+
+In scalar context return the number of sheets in the book.
+In list context return the labels of the sheets in the book.
+
+=head3 sheet
+
+ my $sheet = $book->sheet (1);     # OO
+ my $sheet = $book->sheet ("Foo"); # OO
+
+Return the numbered or named sheet out of the book. Will return C<undef> if
+there is no match. Will not work for sheets I<named> with a number between 1
+and the number of sheets in the book.
+
+If defined, the returned sheet will be of class C<Spreadsheet::Read::Sheet>.
+
+=head3 add
+
+ my $book = ReadData ("file.csv");
+ Spreadsheet::Read::add ($book, "file.xlsx");
+
+ my $book = Spreadsheet::Read->new ("file.csv");
+ $book->add ("file.xlsx"); # OO
+
+=head2 Methods on sheets
+
+=head3 maxcol
+
+ my $col = $sheet->maxcol;
+
+Return the index of the last in-use column in the sheet.
+
+=head3 maxrow
+
+ my $row = $sheet->maxrow;
+
+Return the index of the last in-use row in the sheet.
+
+=head3 cell
+
+ my $cell = $sheet->cell ("A3");
+ my $cell = $sheet->cell (1, 3);
+
+Return the value for a cell. Using tags will return the formatted value,
+using column and row will return unformatted value.
+
+=head3 cr2cell
+
+ my $cell = $sheet->cr2cell (col, row);
+
+C<cr2cell ()> converts a C<(column, row)> pair (1 based) to the
+traditional cell notation:
+
+  my $cell = $sheet->cr2cell ( 4, 14); # $cell now "D14"
+  my $cell = $sheet->cr2cell (28,  4); # $cell now "AB4"
+
+=head3 cell2cr
+
+ my ($col, $row) = $sheet->cell2cr ($cell);
+
+C<cell2cr ()> converts traditional cell notation to a C<(column, row)>
+pair (1 based):
+
+  my ($col, $row) = $sheet->cell2cr ("D14"); # returns ( 4, 14)
+  my ($col, $row) = $sheet->cell2cr ("AB4"); # returns (28,  4)
+
+=head3 row
+
+ my @row = $sheet->row ($row);
+
+Get full row of formatted values (like C<< $sheet->{A3} .. $sheet->{G3} >>)
+
+Note that the indexes in the returned list are 0-based.
+
+=head3 cellrow
+
+ my @row = $sheet->cellrow ($row);
+
+Get full row of unformatted values (like C<< $sheet->{cell}[1][3] .. $sheet->{cell}[7][3] >>)
+
+Note that the indexes in the returned list are 0-based.
+
+=head3 rows
+
+ my @rows = $sheet->rows ();
+
+Convert C<{cell}>'s C<[column][row]> to a C<[row][column]> list.
+
+Note that the indexes in the returned list are 0-based, where the
+index in the C<{cell}> entry is 1-based.
+
 =head2 Using CSV
 
 In case of CSV parsing, L<C<ReadData>|/ReadData> will use the first line of
@@ -1223,6 +1503,10 @@ is made to analyze and store field attributes like this:
 This has now been partially implemented, mainly for Excel, as the other
 parsers do not (yet) support all of that. YMMV.
 
+If a cell itself is not hidden, but the parser holds the information that
+either the row or the column (or both) the field is in is hidden, the flag
+is inherited into the cell attributes.
+
 =head3 Merged cells
 
 Note that only
@@ -1455,12 +1739,6 @@ API of that parser reasonable fits in my approach, I will consider to
 implement the glue layer, or apply patches to do so as long as these
 match what F<CONTRIBUTING.md> describes.
 
-=item Add an OO interface
-
-Consider making the ref an object, though I currently don't see the big
-advantage (yet). Maybe I'll make it so that it is a hybrid functional /
-OO interface.
-
 =back
 
 =head1 SEE ALSO
@@ -1490,16 +1768,6 @@ but for new Microsoft Excel 2007+ files (.xlsx). They have the same API.
 This module uses L<XML::Twig|http://metacpan.org/release/XML-Twig> to parse the
 internal XML.
 
-=item Spreadsheet::XLSX::Reader::LibXML
-
-L<Spreadsheet::XLSX::Reader::LibXML|http://metacpan.org/release/Spreadsheet-XLSX-Reader-LibXML>
-is an alternative Microsoft 2007+ parser that uses
-L<XML::LibXML|http://metacpan.org/release/XML-LibXML> to parse the internal XML.
-
-Work in progress. Much is relying on undocumented internals. The author gave up
-on making this work, so it is not enabled by default. Feel free submit patches
-to make it work.
-
 =item Spreadsheet::XLSX
 
 See L<Spreadsheet::XLSX|http://metacpan.org/release/Spreadsheet-XLSX>
@@ -1552,7 +1820,7 @@ H.Merijn Brand, <h.m.brand@xs4all.nl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2015 H.Merijn Brand
+Copyright (C) 2005-2016 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
